@@ -171,8 +171,12 @@ repos = OrderedDict({
 
     'docker': ['cloudmesh-cmsd'],
 
+    'docker-command': ['cloudmesh-cmsd',
+                       'cloudmesh-docker'],
+
     'iu': cms + cloud + [   # add cloud so the yaml file gets created
-        'cloudmesh-iu'
+        'cloudmesh-iu',
+        # cloudmesh-notebook
     ],
 
     'batch': cloud + [
@@ -263,7 +267,7 @@ repos = OrderedDict({
         'cloudmesh-javascript',
         'cloudmesh-nist',
         'cloudmesh-nn',
-        'cloudmesh-notebooks',
+        'cloudmesh-notebook',
         'cloudmesh-openapi',
         'cloudmesh-oracle',
         'cloudmesh-redshift',
